
.. image:: logo.png
    :width: 50%
    :align: center

..  MoviePy
..  =======



MoviePy is a Python module for video editing, which can be used for basic operations (like cuts, concatenations, title insertions), video compositing (a.k.a. non-linear editing), video processing, or to create advanced effects. It can read and write the most common video formats, including GIF.

Here it is in action (run in an IPython Notebook):

.. image:: demo_preview.jpeg
    :width: 500px
    :align: center

User Guide
------------

.. toctree::
   :maxdepth: 1
   
   install
   getting_started/getting_started
   gallery
   examples/examples
   FAQ
   ref/ref
    
Contribute !
--------------

MoviePy is an open source software originally written by Zulko_ and released under the MIT licence. It works on Windows, Mac, and Linux, with Python 2 or Python 3. The code is hosted on Github_, where you can push improvements, report bugs and ask for help. There is also a MoviePy forum on Reddit_ and a mailing list on librelist_ .

.. raw:: html

    <a href="https://twitter.com/share" class="twitter-share-button"
    data-text="MoviePy - Video editing with Python" data-size="large" data-hashtags="MoviePy">Tweet
    </a>
    <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';
    if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';
    fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');
    </script>
    
    <iframe src="http://ghbtns.com/github-btn.html?user=Zulko&repo=moviepy&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="152px" height="30px"></iframe>
..    <a href="https://github.com/Zulko/moviepy">
..    <img style="position: absolute; top: 0; right: 0; border: 0;"
..    src="https://s3.amazonaws.com/github/ribbons/forkme_right_red_aa0000.png"
..    alt="Fork me on GitHub"></a>

.. _PyPI: https://pypi.python.org/pypi/moviepy
.. _Zulko: https://github.com/Zulko/
.. _Stackoverflow: http://stackoverflow.com/
.. _Github: https://github.com/Zulko/moviepy
.. _Reddit: http://www.reddit.com/r/moviepy/
.. _librelist: mailto:moviepy@librelist.com
